# qrcodeT
This simple library generates text-based QR codes to be used directly in the console (terminal).
## Usage
You can directly use this library to create a QR code from a text and directly print it on the console:
```
import qrcodeT
qrcodeT.qrcodeT('https://github.com/Khalil-Youssefi/qrcodeT')
```
and the output will be:

![sample output](./qrcodeT_sample.JPG)
